Bug 1230759: Part 1 - updated the libsrtp update script draft
authorNils Ohlmeier [:drno] <drno@ohlmeier.org>
Sun, 12 Nov 2017 08:11:28 +0800
changeset 702420 363cc293242734dc02d12e8b793000c1f5b90fcf
parent 702247 960f50c2e0a991ab2ab313132e69fb2c96cb7866
child 702421 a8ed8252fdce6f6a8ab1e3b97255ea0408f52c4d
push id90487
push userdrno@ohlmeier.org
push dateThu, 23 Nov 2017 07:07:55 +0000
bugs1230759
milestone59.0a1
Bug 1230759: Part 1 - updated the libsrtp update script MozReview-Commit-ID: 3HVMaj0YHJ1
netwerk/srtp/update_srtp.sh
--- a/netwerk/srtp/update_srtp.sh
+++ b/netwerk/srtp/update_srtp.sh
@@ -1,32 +1,29 @@
 #!/bin/bash
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 # assume $1 is the directory with a SVN checkout of the libsrtp source
 #
-# srtp source is available (via cvs) at:
-# cvs -d:pserver:anonymous@srtp.cvs.sourceforge.net:/cvsroot/srtp login
-# cvs -z3 -d:pserver:anonymous@srtp.cvs.sourceforge.net:/cvsroot/srtp co -P srtp
+# srtp source is available at: https://github.com/cisco/libsrtp/
 #
 # also assumes we've made *NO* changes to the SRTP sources!  If we do, we have to merge by
 # hand after this process, or use a more complex one.
 #
 # For example, one could update an srtp library import head, and merge back to default.  Or keep a
 # separate repo with this in it, and pull from there to m-c and merge.
 if [ "$1" ] ; then
-  export date=`date`
-#  export revision=`(cd $1; svnversion -n)`
-  export CVSREAD=0
-  cp -rf $1/srtp $1/crypto $1/include $1/VERSION $1/LICENSE $1/README $1/configure.in netwerk/srtp/src
+  DATE=`date`
+  REVISION=`(cd $1; git log --pretty=oneline | head -1 | cut -c 1-40)`
+  cp -rf $1/srtp $1/crypto $1/include $1/test $1/VERSION $1/LICENSE $1/README.md netwerk/srtp/src
 
-  hg addremove netwerk/srtp/src --include "netwerk/srtp/src/VERSION" --include "netwerk/srtp/src/LICENSE" --include "netwerk/srtp/src/configure.in" --include "netwerk/srtp/src/README" --include "**.c" --include "**.h" --similarity 90
+  hg addremove netwerk/srtp/src --include "netwerk/srtp/src/VERSION" --include "netwerk/srtp/src/LICENSE" --include "netwerk/srtp/src/README.md" --include "**.c" --include "**.h" --similarity 90
 
-  echo "srtp updated from CVS on $date" >> netwerk/srtp/srtp_update.log
-  echo "srtp updated from CVS on $date"
+  echo "srtp updated to revision $REVISION from git on $DATE" >> netwerk/srtp/srtp_update.log
+  echo "srtp updated to revision $REVISION from git on $DATE"
   echo "WARNING: reapply any local patches!"
 else
   echo "usage: $0 path_to_srtp_directory"
@@ -1,32 +1,29 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-# assume $1 is the directory with a SVN checkout of the libsrtp source
+# assume $1 is the directory with a git checkout of the libsrtp source
 #
   echo "run from the root of your m-c clone"
 fi